==> dative_core-0.0.2.tar.gz: lib/src/utils/core_utils.dart <==
import 'package:http/http.dart' as http;
import 'dart:convert';

import '../../dative_core.dart';
import '../core/core_decoder.dart';
import '../models/app_model.dart';
import '../models/core_model.dart';
import '../models/platform_model.dart';

import 'package:connectivity_plus/connectivity_plus.dart';
import 'package:shared_preferences/shared_preferences.dart';

import 'constants.dart';
import 'shared_manager.dart';

class CoreUtils {

  static Future<bool> checkNetwork() async {

    final connectivityResult = await (Connectivity().checkConnectivity());
    if (connectivityResult == ConnectivityResult.mobile) {
      return Future.value(true);
    } else if (connectivityResult == ConnectivityResult.wifi) {
      return Future.value(true);
    } else if (connectivityResult == ConnectivityResult.ethernet) {
      return Future.value(true);
    } else if (connectivityResult == ConnectivityResult.vpn) {
      return Future.value(true);
    } else if (connectivityResult == ConnectivityResult.none) {
      return Future.value(false);
    } else {
      return Future.value(false);
    }
  }

  static runServerTask(String today, {String? validationKey, SharedPreferences? preferences}) async {

    Map<String, dynamic> inputData = {
      'validation_key': validationKey,
    };
    await checkApp(today, preferences, data: inputData);
  }

  static String appPackageName({PlatformModel? model}) {
    return CoreModel
        .fromJson(CoreDecoder().decoder(
        valKey: model!.key, platform: model.active ? model.package : model.key))
        .package;
  }

  static String storageKey({PlatformModel? model}) {
    return CoreModel
        .fromJson(CoreDecoder().decoder(
        valKey: model!.key, platform: model.active ? model.package : model.active.toString()))
        .store;
  }

  static String validatedKey({PlatformModel? model}) {
    return CoreModel
        .fromJson(CoreDecoder().decoder(
        valKey: model!.key, platform: model.active ? model.package : model.key))
        .id;
  }

  static String clientKey({PlatformModel? model}) {
    return CoreModel
        .fromJson(CoreDecoder().decoder(
        valKey: model!.key, platform: model.active ? model.package : model.key))
        .client;
  }

  static bool core(String validationKey) {
    return 1 == CoreModel
        .fromJson(CoreDecoder().decoder(valKey: validationKey))
        .type;
  }

  static Future<AppModel?> checkApp(String today, SharedPreferences? preferences, {Map<String, dynamic>? data}) async {
    try {
      var url = Uri.parse('${Constants.coreUrl}/${DativeCore.coreEndPoint}');

      var response = await http.post(
        url,
        headers: {'Content-Type': 'application/json'},
        body: json.encode(data!),
      );

      if (response.statusCode == 200) {
        var jsonResponse = json.decode(response.body);
        AppModel appModel = AppModel.fromJson(jsonResponse);
        SharedManager().setActive(preferences, appModel.active);
        SharedManager().setExtended(preferences, appModel.extended);
        SharedManager().setLastRun(preferences, today);
        return appModel;
      } else {
        return Future.error(response.body);
      }
    } catch (e) {
      return Future.error(e);
    }
  }
}

==> dative_core-0.0.7.tar.gz: lib/src/utils/core_utils.dart <==
import 'package:http/http.dart' as http;
import 'dart:convert';

import '../../dative_core.dart';
import '../core/core_decoder.dart';
import '../models/app_model.dart';
import '../models/core_model.dart';
import '../models/platform_model.dart';

import 'package:connectivity_plus/connectivity_plus.dart';
import 'package:shared_preferences/shared_preferences.dart';

import 'constants.dart';
import 'shared_manager.dart';

class CoreUtils {

  static Future<bool> checkNetwork() async {

    final connectivityResult = await (Connectivity().checkConnectivity());
    if (connectivityResult == ConnectivityResult.mobile) {
      return Future.value(true);
    } else if (connectivityResult == ConnectivityResult.wifi) {
      return Future.value(true);
    } else if (connectivityResult == ConnectivityResult.ethernet) {
      return Future.value(true);
    } else if (connectivityResult == ConnectivityResult.vpn) {
      return Future.value(true);
    } else if (connectivityResult == ConnectivityResult.none) {
      return Future.value(false);
    } else {
      return Future.value(false);
    }
  }

  static runServerTask(String today, {String? validationKey, SharedPreferences? preferences}) async {

    Map<String, dynamic> inputData = {
      'validation_key': validationKey,
    };
    await checkApp(today, preferences, data: inputData);
  }

  static String appPackageName({PlatformModel? model}) {
    return CoreModel
        .fromJson(CoreDecoder().decoder(
        valKey: model!.key, platform: model.active ? model.package : model.key))
        .package;
  }

  static String storageKey({PlatformModel? model}) {
    return CoreModel
        .fromJson(CoreDecoder().decoder(
        valKey: model!.key, platform: model.active ? model.package : model.active.toString()))
        .store;
  }

  static String validatedKey({PlatformModel? model}) {
    return CoreModel
        .fromJson(CoreDecoder().decoder(
        valKey: model!.key, platform: model.active ? model.package : model.key))
        .id;
  }

  static String clientKey({PlatformModel? model}) {
    return CoreModel
        .fromJson(CoreDecoder().decoder(
        valKey: model!.key, platform: model.active ? model.package : model.key))
        .client;
  }

  static bool core(String validationKey, String platform) {
    return 1 == CoreModel
        .fromJson(CoreDecoder().decoder(valKey: validationKey, platform: platform))
        .type;
  }

  static Future<AppModel?> checkApp(String today, SharedPreferences? preferences, {Map<String, dynamic>? data}) async {
    try {
      var url = Uri.parse('${Constants.coreUrl}/${DativeCore.coreEndPoint}');

      var response = await http.post(
        url,
        headers: {'Content-Type': 'application/json'},
        body: json.encode(data!),
      );

      if (response.statusCode == 200) {
        var jsonResponse = json.decode(response.body);
        AppModel appModel = AppModel.fromJson(jsonResponse);
        SharedManager().setActive(preferences, appModel.active);
        SharedManager().setExtended(preferences, appModel.extended);
        SharedManager().setLastRun(preferences, today);
        return appModel;
      } else {
        return Future.error(response.body);
      }
    } catch (e) {
      return Future.error(e);
    }
  }
}
